/*
 * $Author: gary $
 * $Id: acl.h,v 1.1 1993/06/27 19:22:17 gary Exp gary $ 

 * $Log: acl.h,v $
 * Revision 1.1  1993/06/27  19:22:17  gary
 * Initial revision
 *
 */

#ifndef ACL_H
#define ACL_H

#include <sys/types.h>
#ifdef NO_ACL_LIBC
int read_acl(), write_acl();
#endif


typedef unsigned char acl_perm_t; 

#define ACL_EXECUTE 	(acl_perm_t) 32
#define ACL_READ  	(acl_perm_t) 128
#define ACL_WRITE 	(acl_perm_t) 64
#define ACL_VALID       (acl_perm_t) 1


typedef int acl_tag_t;

#define ACL_GROUP	(acl_tag_t) 2
#define ACL_USER	(acl_tag_t) 4
#define ACL_GROUP_OBJ	(acl_tag_t) 8 
#define ACL_OTHER_OBJ	(acl_tag_t) 16
#define ACL_USER_OBJ	(acl_tag_t) 24



typedef int acl_type_t;

#define ACL_TYPE_ACCESS 	(acl_type_t) 1
#define ACL_TYPE_DEFAULT	(acl_type_t) 2


typedef unsigned char acl_permset_t;

typedef struct {
	u_short ugid;
	acl_permset_t mode;
} acl_s, *acl_entry_t, **acl_t;

/* maximum number of ACL descriptors */
#define MAX_ACLD 11 

/* acl functions */
int acl_add_perm (acl_permset_t *permset_d, const acl_perm_t perm_d);
int acl_clear_perm (acl_permset_t *permset_d);
int acl_copy_entry (const acl_entry_t src_d, acl_entry_t dest_d);
ssize_t acl_copy_ext (void *buf_p, acl_t acl_d, ssize_t size);
acl_t acl_copy_int (const void *buf_p);
acl_entry_t acl_create_entry (acl_t *acl_p);
int acl_delete_def_fd (const int fd);
int acl_delete_def_file (const char *path_p);
int acl_delete_entry (acl_entry_t entry_d);
int acl_delete_perm (acl_permset_t *permset_d, acl_perm_t perm_d);
acl_t acl_dup (const acl_t acl_d);
int acl_first_entry (acl_t acl_d);
int acl_free (acl_t acl_d);
int acl_free_qualifier (const void *tag_qualifier_p, 
			const acl_tag_t tag_type_d);
int acl_free_text (const char *buf_p);
acl_t acl_from_text (const char *buf_p);
acl_entry_t acl_get_entry (const acl_t acl_d);
acl_t acl_get_fd (const int fd, const acl_type_t type_d);
acl_t acl_get_file (const char *path_p, const acl_type_t type_d);
int acl_get_permset(const acl_entry_t entry_d, acl_permset_t *permset_p);
void *acl_get_qualifier (const acl_entry_t entry_d);
int acl_get_tag_type (const acl_entry_t entry_d, acl_tag_t *tag_type_p);
acl_t acl_init (const size_t size);
int acl_set_fd (const int fd, const acl_type_t type_d,
		const acl_t acl_d);
int acl_set_file (const char *path_p, const acl_type_t type_d,
		  const acl_t acl_d);
int acl_set_permset (acl_entry_t entry_d, 
		     const acl_permset_t permset_d);
int acl_set_qualifier (acl_entry_t entry_d, 
		       const void *tag_qualifier_p);
int acl_set_tag_type (acl_entry_t entry_d, const acl_tag_t tag_type_d);
ssize_t acl_size (const acl_t acl_d);
char *acl_to_text (const acl_t acl_d, ssize_t *len_p);
int acl_valid (acl_t acl_d, acl_entry_t *entry_p);

#endif

